Index: trunk/psModules/src/camera/pmHDUUtils.c
===================================================================
--- trunk/psModules/src/camera/pmHDUUtils.c	(revision 18554)
+++ trunk/psModules/src/camera/pmHDUUtils.c	(revision 21363)
@@ -18,13 +18,13 @@
 
     for (int i = 0; i < fpa->chips->n; i++) {
-	pmChip *chip = fpa->chips->data[i];
-	if (!chip) continue;
-	if (chip->hdu) return chip->hdu;
-	if (!chip->cells) continue;
-	for (int j = 0; j < chip->cells->n; j++) {
-	    pmCell *cell = chip->cells->data[j];
-	    if (!cell) continue;
-	    if (cell->hdu) return cell->hdu;
-	}
+        pmChip *chip = fpa->chips->data[i];
+        if (!chip) continue;
+        if (chip->hdu) return chip->hdu;
+        if (!chip->cells) continue;
+        for (int j = 0; j < chip->cells->n; j++) {
+            pmCell *cell = chip->cells->data[j];
+            if (!cell) continue;
+            if (cell->hdu) return cell->hdu;
+        }
     }
     return NULL;
@@ -158,13 +158,13 @@
 
     INDENT(fd, level + 1);
-    if (hdu->weights) {
-        fprintf(fd, "Weights:\n");
-        for (long i = 0; i < hdu->weights->n; i++) {
-            psImage *weight = hdu->weights->data[i]; // Weight image of interest
+    if (hdu->variances) {
+        fprintf(fd, "Variances:\n");
+        for (long i = 0; i < hdu->variances->n; i++) {
+            psImage *variance = hdu->variances->data[i]; // Variance image of interest
             INDENT(fd, level + 2);
-            fprintf(fd, "%ld: %dx%d\n", i, weight->numCols, weight->numRows);
+            fprintf(fd, "%ld: %dx%d\n", i, variance->numCols, variance->numRows);
         }
     } else {
-        fprintf(fd, "NO weights.\n");
+        fprintf(fd, "NO variances.\n");
     }
 
